@@ -18,14 +18,18 @@ class Logger(object):
         self.url = url
         self.port = port
         self.log_name = log_name
+        self.is_valid()
 
     def log_to_remote(self, log: LogSerializer) -> None:
-        log.data['log_name'] = self.log_name
         requests.post(
-            url=f"{self.scheme}://{self.url}:{self.port}/",
+            url=f"{self.scheme}://{self.url}:{self.port}/{self.log_name}",
             json=log.data
         )
 
+    def is_valid(self):
+        # TODO: implement validator
+        pass
+
     def log_to_file() -> None:
         raise NotImplementedError
 
